@@ -1,10 +1,13 @@
-__version__ = '0.0.78'
+__version__ = '0.1.2'
 
 import functools
 import logging
 import traceback
 
 from flask import Blueprint
+from lesscode_utils.encryption_algorithm import AES
+
+from lesscode_flask.export_data.data_download_handler import download_func_dict
 from lesscode_flask.utils.decorator.cache import deal_cache
 
 
@@ -15,11 +18,14 @@ class SQ_Blueprint(Blueprint):
         super().__init__(name=name, url_prefix=url_prefix, **kwargs)
 
     def decorator_handler(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
-                          content_type: str = "json", methods=['POST']):
+                          content_type: str = "json", methods=['POST'], export_enable: bool = False):
         options = {"methods": methods}
 
         def decorator(func):
             path = url if url else "/{}".format(func.__name__)
+            if export_enable:
+                download_key = AES.encrypt(func.__module__)[:16] + "." + func.__name__
+                download_func_dict[download_key] = func
 
             @functools.wraps(func)
             def wrapper(*args, **kwargs):
@@ -31,9 +37,13 @@ class SQ_Blueprint(Blueprint):
                     except Exception as e:
                         logging.error(traceback.format_exc())
                         data = func(*args, **kwargs)
-                    return data
-                # 如果没有开启缓存，或者缓存未命中，则执行原始函数
-                data = func(*args, **kwargs)
+                else:
+                    # 如果没有开启缓存，或者缓存未命中，则执行原始函数
+                    data = func(*args, **kwargs)
+                if isinstance(data, dict) and export_enable:
+                    data.update({
+                        "download_key": download_key
+                    })
                 return data
 
             wrapper._title = title
@@ -45,11 +55,11 @@ class SQ_Blueprint(Blueprint):
         return decorator
 
     def post_route(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
-                   content_type: str = "json", methods=['POST']):
-        decorator = self.decorator_handler(title, url, cache_enalbe, cache_ex, content_type, methods)
+                   content_type: str = "json", methods=['POST'], export_enable: bool = False):
+        decorator = self.decorator_handler(title, url, cache_enalbe, cache_ex, content_type, methods, export_enable)
         return decorator
 
     def get_route(self, title: str, url: str = None, cache_enalbe: bool = False, cache_ex: int = 3600 * 10,
                   content_type: str = "json", methods=['GET']):
         decorator = self.decorator_handler(title, url, cache_enalbe, cache_ex, content_type, methods)
-        return decorator
\ No newline at end of file
+        return decorator
