@@ -15,8 +15,6 @@ try:
 except ImportError as e:
     raise Exception(f"sqlparse is not exist,run:pip install sqlparse==0.5.1")
 
-
-
 from redash import settings, utils
 from redash.utils.requests_session import (
     # UnacceptableAddressException,
@@ -56,6 +54,10 @@ TYPE_DATE = "date"
 SUPPORTED_COLUMN_TYPES = set([TYPE_INTEGER, TYPE_FLOAT, TYPE_BOOLEAN, TYPE_STRING, TYPE_DATETIME, TYPE_DATE])
 
 
+class QueryExecutionError(Exception):
+    pass
+
+
 def split_sql_statements(query):
     def strip_trailing_comments(stmt):
         idx = len(stmt.tokens) - 1
@@ -516,7 +518,8 @@ def with_ssh_tunnel(query_runner, details):
                     sshtunnel = import_module("sshtunnel")
                 except ImportError as e:
                     raise Exception(f"sshtunnel is not exist,run:pip install sshtunnel==0.4.0")
-                server = stack.enter_context(sshtunnel.open_tunnel(bastion_address, remote_bind_address=remote_address, **auth))
+                server = stack.enter_context(
+                    sshtunnel.open_tunnel(bastion_address, remote_bind_address=remote_address, **auth))
             except Exception as error:
                 raise type(error)("SSH tunnel: {}".format(str(error)))
 
