@@ -1,25 +1,11 @@
 import logging
-import sys
-import urllib.request
-import urllib.parse
 import urllib.error
-from importlib import import_module
-
-try:
-    requests = import_module("requests")
-except ImportError as e:
-    raise Exception(f"requests is not exist,run:pip install requests==2.32.3")
-from requests.auth import HTTPBasicAuth
+import urllib.parse
 
+from lesscode_flask.utils.request.request import get_basic_auth, sync_common_request_origin
 from redash.query_runner import *
 from redash.utils import json_dumps, json_loads
 
-try:
-    import http.client as http_client
-except ImportError:
-    # Python 2
-    import http.client as http_client
-
 logger = logging.getLogger(__name__)
 
 ELASTICSEARCH_TYPES_MAPPING = {
@@ -75,8 +61,6 @@ class BaseElasticSearch(BaseQueryRunner):
         self.syntax = "json"
 
         if self.DEBUG_ENABLED:
-            http_client.HTTPConnection.debuglevel = 1
-
             # you need to initialize logging, otherwise you will not see anything from requests
             logging.basicConfig()
             logging.getLogger().setLevel(logging.DEBUG)
@@ -94,25 +78,18 @@ class BaseElasticSearch(BaseQueryRunner):
         basic_auth_password = self.configuration.get("basic_auth_password", None)
         self.auth = None
         if basic_auth_user and basic_auth_password:
-            self.auth = HTTPBasicAuth(basic_auth_user, basic_auth_password)
+            self.auth = get_basic_auth(basic_auth_user, basic_auth_password)
 
     def _get_mappings(self, url):
-        mappings = {}
         error = None
         try:
-            r = requests.get(url, auth=self.auth)
+            r = sync_common_request_origin(url=url, method="get", auth=self.auth)
             r.raise_for_status()
 
             mappings = r.json()
-        except requests.HTTPError as e:
+        except Exception as e:
             logger.exception(e)
-            error = "Failed to execute query. Return Code: {0}   Reason: {1}".format(
-                r.status_code, r.text
-            )
-            mappings = None
-        except requests.exceptions.RequestException as e:
-            logger.exception(e)
-            error = "Connection refused"
+            error = f"Failed to execute query. Reason: {e}"
             mappings = None
 
         return mappings, error
@@ -178,10 +155,10 @@ class BaseElasticSearch(BaseQueryRunner):
         return list(schema.values())
 
     def _parse_results(
-        self, mappings, result_fields, raw_result, result_columns, result_rows
+            self, mappings, result_fields, raw_result, result_columns, result_rows
     ):
         def add_column_if_needed(
-            mappings, column_name, friendly_name, result_columns, result_columns_index
+                mappings, column_name, friendly_name, result_columns, result_columns_index
         ):
             if friendly_name not in result_columns_index:
                 result_columns.append(
@@ -210,7 +187,7 @@ class BaseElasticSearch(BaseQueryRunner):
             row[key] = value
 
         def collect_aggregations(
-            mappings, rows, parent_key, data, row, result_columns, result_columns_index
+                mappings, rows, parent_key, data, row, result_columns, result_columns_index
         ):
             if isinstance(data, dict):
                 for key, value in data.items():
@@ -345,20 +322,13 @@ class BaseElasticSearch(BaseQueryRunner):
 
     def test_connection(self):
         try:
-            r = requests.get(
-                "{0}/_cluster/health".format(self.server_url), auth=self.auth
-            )
+            r = sync_common_request_origin(url="{0}/_cluster/health".format(self.server_url), method="get",
+                                           auth=self.auth
+                                           )
             r.raise_for_status()
-        except requests.HTTPError as e:
+        except Exception as e:
             logger.exception(e)
-            raise Exception(
-                "Failed to execute query. Return Code: {0}   Reason: {1}".format(
-                    r.status_code, r.text
-                )
-            )
-        except requests.exceptions.RequestException as e:
-            logger.exception(e)
-            raise Exception("Connection refused")
+            raise Exception(f"Failed to execute query.Reason: {e}")
 
 
 class Kibana(BaseElasticSearch):
@@ -367,10 +337,10 @@ class Kibana(BaseElasticSearch):
         return True
 
     def _execute_simple_query(
-        self, url, auth, _from, mappings, result_fields, result_columns, result_rows
+            self, url, auth, _from, mappings, result_fields, result_columns, result_rows
     ):
         url += "&from={0}".format(_from)
-        r = requests.get(url, auth=self.auth)
+        r = sync_common_request_origin(url=url, method="get", auth=self.auth)
         r.raise_for_status()
 
         raw_result = r.json()
@@ -442,15 +412,9 @@ class Kibana(BaseElasticSearch):
 
             # json_data = json_dumps({"columns": result_columns, "rows": result_rows})
             json_data = {"columns": result_columns, "rows": result_rows}
-        except requests.HTTPError as e:
+        except Exception as e:
             logger.exception(e)
-            error = "Failed to execute query. Return Code: {0}   Reason: {1}".format(
-                r.status_code, r.text
-            )
-            json_data = None
-        except requests.exceptions.RequestException as e:
-            logger.exception(e)
-            error = "Connection refused"
+            error = f"Failed to execute query. Reason: {e}"
             json_data = None
 
         return json_data, error
@@ -488,7 +452,7 @@ class ElasticSearch(BaseElasticSearch):
 
             logger.debug("Using URL: %s", url)
             logger.debug("Using query: %s", query_dict)
-            r = requests.get(url, json=query_dict, auth=self.auth)
+            r = sync_common_request_origin(url=url, method="get", json=query_dict, auth=self.auth)
             r.raise_for_status()
             logger.debug("Result: %s", r.json())
 
@@ -499,18 +463,9 @@ class ElasticSearch(BaseElasticSearch):
             )
 
             json_data = json_dumps({"columns": result_columns, "rows": result_rows})
-        except (KeyboardInterrupt, JobTimeoutException):
+        except Exception as e:
             logger.exception(e)
-            raise
-        except requests.HTTPError as e:
-            logger.exception(e)
-            error = "Failed to execute query. Return Code: {0}   Reason: {1}".format(
-                r.status_code, r.text
-            )
-            json_data = None
-        except requests.exceptions.RequestException as e:
-            logger.exception(e)
-            error = "Connection refused"
+            error = f"Failed to execute query.  Reason: {e}"
             json_data = None
 
         return json_data, error
